# Getting started

 - Install NGSolve (`conda install -c mhochsteger ngsolve`)
 - Install Pyside2 (`conda install -c conda-forge pyside2`)
```
mkdir build && cd build
cmake ..
make install
cd ../demo
python3 example.py
```
